Index: trunk/psLib/src/sysUtils/psMemory.c
===================================================================
--- trunk/psLib/src/sysUtils/psMemory.c	(revision 4401)
+++ trunk/psLib/src/sysUtils/psMemory.c	(revision 4444)
@@ -8,6 +8,6 @@
 *  @author Robert Lupton, Princeton University
 *
-*  @version $Revision: 1.57 $ $Name: not supported by cvs2svn $
-*  @date $Date: 2005-06-27 20:38:12 $
+*  @version $Revision: 1.58 $ $Name: not supported by cvs2svn $
+*  @date $Date: 2005-07-01 03:57:39 $
 *
 *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -84,11 +84,11 @@
 /*
  * Default callback for both allocate and free. Note that the
  * value of p_psMemAllocateID/p_psMemFreeID is incremented
  * by the return value (so returning 0 means that the callback
  * isn't resignalled)
  */
-static psMemId memAllocateCallbackDefault(const psMemBlock* ptr)
-{
-    static psMemId incr = 0; // "p_psMemAllocateID += incr"
+static psMemId memAllocCallbackDefault(const psMemBlock* ptr)
+{
+    static psMemId incr = 0; // "p_psMemAllocID += incr"
 
     return incr;
@@ -102,5 +102,5 @@
 }
 
-static void memProblemCallbackDefault(const psMemBlock* ptr, const char *file, psS32 lineno)
+static void memProblemCallbackDefault( psMemBlock* ptr, const char *file, unsigned int lineno)
 {
     if (ptr->refCounter < 1) {
@@ -158,5 +158,5 @@
  * The default callbacks
  */
-static psMemAllocateCallback memAllocateCallback = memAllocateCallbackDefault;
+static psMemAllocCallback memAllocCallback = memAllocCallbackDefault;
 static psMemFreeCallback memFreeCallback = memFreeCallbackDefault;
 static psMemProblemCallback memProblemCallback = memProblemCallbackDefault;
@@ -194,12 +194,12 @@
  * Call the callbacks when these IDs are allocated/freed
  */
-psMemId p_psMemAllocateID = 0;       // notify user this block is allocated
+psMemId p_psMemAllocID = 0;       // notify user this block is allocated
 psMemId p_psMemFreeID = 0;   // notify user this block is freed
 
-psMemId psMemAllocateCallbackSetID(psMemId id)
-{
-    psMemId old = p_psMemAllocateID;
-
-    p_psMemAllocateID = id;
+psMemId psMemAllocCallbackSetID(psMemId id)
+{
+    psMemId old = p_psMemAllocID;
+
+    p_psMemAllocID = id;
 
     return old;
@@ -215,12 +215,12 @@
 }
 
-psMemAllocateCallback psMemAllocateCallbackSet(psMemAllocateCallback func)
-{
-    psMemFreeCallback old = memAllocateCallback;
+psMemAllocCallback psMemAllocCallbackSet(psMemAllocCallback func)
+{
+    psMemFreeCallback old = memAllocCallback;
 
     if (func != NULL) {
-        memAllocateCallback = func;
+        memAllocCallback = func;
     } else {
-        memAllocateCallback = memAllocateCallbackDefault;
+        memAllocCallback = memAllocCallbackDefault;
     }
 
@@ -286,5 +286,5 @@
 }
 
-psPtr p_psAlloc(size_t size, const char *file, psS32 lineno)
+psPtr p_psAlloc(size_t size, const char *file, unsigned int lineno)
 {
 
@@ -363,6 +363,6 @@
 
     // Did the user ask to be informed about this allocation?
-    if (ptr->id == p_psMemAllocateID) {
-        p_psMemAllocateID += memAllocateCallback(ptr);
+    if (ptr->id == p_psMemAllocID) {
+        p_psMemAllocID += memAllocCallback(ptr);
     }
     // And return the user the memory that they allocated
@@ -370,5 +370,5 @@
 }
 
-psPtr p_psRealloc(psPtr vptr, size_t size, const char *file, psS32 lineno)
+psPtr p_psRealloc(psPtr vptr, size_t size, const char *file, unsigned int lineno)
 {
     size = (size < recycleBinSize[0]) ? recycleBinSize[0] : size; // set the minimum size to allocate
@@ -416,6 +416,6 @@
 
         // Did the user ask to be informed about this allocation?
-        if (ptr->id == p_psMemAllocateID) {
-            p_psMemAllocateID += memAllocateCallback(ptr);
+        if (ptr->id == p_psMemAllocID) {
+            p_psMemAllocID += memAllocCallback(ptr);
         }
 
@@ -424,5 +424,5 @@
 }
 
-void p_psFree(psPtr vptr, const char *file, psS32 lineno)
+void p_psFree(psPtr vptr, const char *file, unsigned int lineno)
 {
     if (vptr == NULL) {
@@ -84,11 +84,11 @@
 /*
  * Default callback for both allocate and free. Note that the
- * value of p_psMemAllocateID/p_psMemFreeID is incremented
+ * value of p_psMemAllocID/p_psMemFreeID is incremented
  * by the return value (so returning 0 means that the callback
  * isn't resignalled)
